public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r12-1203] arc: Don't allow millicode thunks with reduced register set CPUs.
@ 2021-06-04  7:21 Claudiu Zissulescu
  0 siblings, 0 replies; only message in thread
From: Claudiu Zissulescu @ 2021-06-04  7:21 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:39e5a954c156f7af16aa1a8f87405433d8031c4e

commit r12-1203-g39e5a954c156f7af16aa1a8f87405433d8031c4e
Author: Claudiu Zissulescu <claziss@synopsys.com>
Date:   Fri Jun 4 10:12:32 2021 +0300

    arc: Don't allow millicode thunks with reduced register set CPUs.
    
    The millicode thunks are not reduced register set safe.  Disable them
    for CPUs having this option on.
    
    gcc/
    2021-06-04  Claudiu Zissulescu  <claziss@synopsys.com>
    
            * config/arc/arc.c (arc_override_options): Disable millicode
            thunks when RF16 is on.
    
    Signed-off-by: Claudiu Zissulescu <claziss@synopsys.com>

Diff:
---
 gcc/config/arc/arc.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/gcc/config/arc/arc.c b/gcc/config/arc/arc.c
index b77d0566386..0d34c964963 100644
--- a/gcc/config/arc/arc.c
+++ b/gcc/config/arc/arc.c
@@ -1451,8 +1451,10 @@ arc_override_options (void)
   if (TARGET_ARC700 && (arc_tune != ARC_TUNE_ARC7XX))
     flag_delayed_branch = 0;
 
-  /* Millicode thunks doesn't work with long calls.  */
-  if (TARGET_LONG_CALLS_SET)
+  /* Millicode thunks doesn't work for long calls.  */
+  if (TARGET_LONG_CALLS_SET
+      /* neither for RF16.  */
+      || TARGET_RF16)
     target_flags &= ~MASK_MILLICODE_THUNK_SET;
 
   /* Set unaligned to all HS cpus.  */


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2021-06-04  7:21 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2021-06-04  7:21 [gcc r12-1203] arc: Don't allow millicode thunks with reduced register set CPUs Claudiu Zissulescu

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).